@@ -2,111 +2,99 @@ from warnings import warn
 
 import numpy as np
 import pandas as pd
-from pandas import Series, DataFrame, MultiIndex
-from pandas.core.indexing import _NDFrameIndexer
+from pandas import DataFrame, MultiIndex, Series
 
-from shapely.geometry.base import BaseGeometry
+from pyproj import CRS
 from shapely.geometry import box
-from shapely.ops import cascaded_union, unary_union
-import shapely.affinity as affinity
+from shapely.geometry.base import BaseGeometry
+from shapely.ops import cascaded_union
 
 import geopandas as gpd
 
+from .array import GeometryArray, GeometryDtype
 
 try:
     from rtree.core import RTreeError
+
     HAS_SINDEX = True
 except ImportError:
+
     class RTreeError(Exception):
         pass
+
     HAS_SINDEX = False
 
 
-def _binary_geo(op, left, right):
-    # type: (str, GeoSeries, GeoSeries) -> GeoSeries
-    """Binary operation on GeoSeries objects that returns a GeoSeries"""
-    from .geoseries import GeoSeries
-    if isinstance(right, GeoPandasBase):
-        left = left.geometry
-        left, right = left.align(right.geometry)
+def is_geometry_type(data):
+    """
+    Check if the data is of geometry dtype.
 
-        if left.crs != right.crs:
-            warn('GeoSeries crs mismatch: {0} and {1}'.format(left.crs,
-                                                              right.crs))
-
-        # intersection can return empty GeometryCollections, and if the result
-        # are only those, numpy will coerce it to empty 2D array
-        data = np.empty(len(left), dtype=object)
-        data[:] = [getattr(this_elem, op)(other_elem)
-                   for this_elem, other_elem in zip(left, right)]
-
-        return GeoSeries(data, index=left.index, crs=left.crs)
-
-    elif isinstance(right, BaseGeometry):
-        # ensure 1D output, see note above
-        data = np.empty(len(left), dtype=object)
-        data[:] = [getattr(s, op)(right) for s in left.geometry]
-        return GeoSeries(data, index=left.index, crs=left.crs)
+    Does not include object array of shapely scalars.
+    """
+    if isinstance(getattr(data, "dtype", None), GeometryDtype):
+        # GeometryArray, GeoSeries and Series[GeometryArray]
+        return True
     else:
-        raise TypeError(type(left), type(right))
+        return False
 
 
-def _binary_op(op, this, other, *args, **kwargs):
-    # type: (str, GeoSeries, GeoSeries, args/kwargs) -> Series[bool]
-    """Binary operation on GeoSeries objects that returns a Series"""
-    if op in ['distance', 'project']:
-        null_value = np.nan
-    elif op == 'relate':
-        null_value = None
-    else:
-        null_value = False
-    if op in ['distance', 'project']:
-        dtype = float
-    elif op == 'relate':
-        dtype = object
-    else:
-        dtype = bool
-
+def _delegate_binary_method(op, this, other, *args, **kwargs):
+    # type: (str, GeoSeries, GeoSeries) -> GeoSeries/Series
+    this = this.geometry
     if isinstance(other, GeoPandasBase):
-
-        this = this.geometry
         this, other = this.align(other.geometry)
 
-        data = np.array(
-            [getattr(this_elem, op)(other_elem, *args, **kwargs)
-             if not this_elem.is_empty | other_elem.is_empty else null_value
-             for this_elem, other_elem in zip(this, other)],
-            dtype=dtype)
-
-        return Series(data, index=this.index)
-
+        if this.crs != other.crs:
+            warn("GeoSeries crs mismatch: {0} and {1}".format(this.crs, other.crs))
+        a_this = GeometryArray(this.values)
+        other = GeometryArray(other.values)
     elif isinstance(other, BaseGeometry):
-        data = np.array(
-            [getattr(s, op)(other, *args, **kwargs) if s else null_value
-             for s in this.geometry],
-            dtype=dtype)
-        return Series(data, index=this.index)
+        a_this = GeometryArray(this.values)
     else:
         raise TypeError(type(this), type(other))
 
+    data = getattr(a_this, op)(other, *args, **kwargs)
+    return data, this.index
 
-def _unary_geo(op, this):
+
+def _binary_geo(op, this, other):
+    # type: (str, GeoSeries, GeoSeries) -> GeoSeries
+    """Binary operation on GeoSeries objects that returns a GeoSeries"""
+    from .geoseries import GeoSeries
+
+    geoms, index = _delegate_binary_method(op, this, other)
+    return GeoSeries(geoms.data, index=index, crs=this.crs)
+
+
+def _binary_op(op, this, other, *args, **kwargs):
+    # type: (str, GeoSeries, GeoSeries, args/kwargs) -> Series[bool/float]
+    """Binary operation on GeoSeries objects that returns a Series"""
+    data, index = _delegate_binary_method(op, this, other, *args, **kwargs)
+    return Series(data, index=index)
+
+
+def _delegate_property(op, this):
+    # type: (str, GeoSeries) -> GeoSeries/Series
+    a_this = GeometryArray(this.geometry.values)
+    data = getattr(a_this, op)
+    if isinstance(data, GeometryArray):
+        from .geoseries import GeoSeries
+
+        return GeoSeries(data.data, index=this.index, crs=this.crs)
+    else:
+        return Series(data, index=this.index)
+
+
+def _delegate_geo_method(op, this, *args, **kwargs):
     # type: (str, GeoSeries) -> GeoSeries
     """Unary operation that returns a GeoSeries"""
     from .geoseries import GeoSeries
-    # ensure 1D output, see note above
-    data = np.empty(len(this), dtype=object)
-    data[:] = [getattr(geom, op) for geom in this.geometry]
+
+    a_this = GeometryArray(this.geometry.values)
+    data = getattr(a_this, op)(*args, **kwargs).data
     return GeoSeries(data, index=this.index, crs=this.crs)
 
 
-def _unary_op(op, this, null_value=False):
-    # type: (str, GeoSeries, Any) -> Series
-    """Unary operation that returns a Series"""
-    return Series([getattr(geom, op, null_value) for geom in this.geometry],
-                  index=this.index, dtype=np.dtype(type(null_value)))
-
-
 class GeoPandasBase(object):
     _sindex = None
     _sindex_generated = False
@@ -116,9 +104,12 @@ class GeoPandasBase(object):
             warn("Cannot generate spatial index: Missing package `rtree`.")
         else:
             from geopandas.sindex import SpatialIndex
-            stream = ((i, item.bounds, idx) for i, (idx, item) in
-                      enumerate(self.geometry.iteritems())
-                      if pd.notnull(item) and not item.is_empty)
+
+            stream = (
+                (i, item.bounds, idx)
+                for i, (idx, item) in enumerate(self.geometry.iteritems())
+                if pd.notnull(item) and not item.is_empty
+            )
             try:
                 self._sindex = SpatialIndex(stream)
             # What we really want here is an empty generator error, or
@@ -141,13 +132,31 @@ class GeoPandasBase(object):
     def area(self):
         """Returns a ``Series`` containing the area of each geometry in the
         ``GeoSeries``."""
-        return _unary_op('area', self, null_value=np.nan)
+        return _delegate_property("area", self)
+
+    @property
+    def crs(self):
+        """
+        The Coordinate Reference System (CRS) represented as a ``pyproj.CRS``
+        object.
+
+        Returns None if the CRS is not set, and to set the value it
+        :getter: Returns a ``pyproj.CRS`` or None. When setting, the value
+        can be anything accepted by :meth:`pyproj.CRS.from_user_input`,
+        such as an authority string (eg "EPSG:4326") or a WKT string.
+        """
+        return self._crs
+
+    @crs.setter
+    def crs(self, value):
+        """Sets the value of the crs"""
+        self._crs = None if not value else CRS.from_user_input(value)
 
     @property
     def geom_type(self):
         """Returns a ``Series`` of strings specifying the `Geometry Type` of each
         object."""
-        return _unary_op('geom_type', self, null_value=None)
+        return _delegate_property("geom_type", self)
 
     @property
     def type(self):
@@ -157,19 +166,19 @@ class GeoPandasBase(object):
     @property
     def length(self):
         """Returns a ``Series`` containing the length of each geometry."""
-        return _unary_op('length', self, null_value=np.nan)
+        return _delegate_property("length", self)
 
     @property
     def is_valid(self):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
         geometries that are valid."""
-        return _unary_op('is_valid', self, null_value=False)
+        return _delegate_property("is_valid", self)
 
     @property
     def is_empty(self):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
         empty geometries."""
-        return _unary_op('is_empty', self, null_value=False)
+        return _delegate_property("is_empty", self)
 
     @property
     def is_simple(self):
@@ -178,21 +187,19 @@ class GeoPandasBase(object):
 
         This is meaningful only for `LineStrings` and `LinearRings`.
         """
-        return _unary_op('is_simple', self, null_value=False)
+        return _delegate_property("is_simple", self)
 
     @property
     def is_ring(self):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
         features that are closed."""
-        # operates on the exterior, so can't use _unary_op()
-        return Series([geom.exterior.is_ring for geom in self.geometry],
-                      index=self.index)
+        return _delegate_property("is_ring", self)
 
     @property
     def has_z(self):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
         features that have a z-component."""
-        return _unary_op('has_z', self, null_value=False)
+        return _delegate_property("has_z", self)
 
     #
     # Unary operations that return a GeoSeries
@@ -202,13 +209,13 @@ class GeoPandasBase(object):
     def boundary(self):
         """Returns a ``GeoSeries`` of lower dimensional objects representing
         each geometries's set-theoretic `boundary`."""
-        return _unary_geo('boundary', self)
+        return _delegate_property("boundary", self)
 
     @property
     def centroid(self):
         """Returns a ``GeoSeries`` of points representing the centroid of each
         geometry."""
-        return _unary_geo('centroid', self)
+        return _delegate_property("centroid", self)
 
     @property
     def convex_hull(self):
@@ -219,7 +226,7 @@ class GeoPandasBase(object):
         containing all the points in each geometry, unless the number of points
         in the geometric object is less than three. For two points, the convex
         hull collapses to a `LineString`; for 1, a `Point`."""
-        return _unary_geo('convex_hull', self)
+        return _delegate_property("convex_hull", self)
 
     @property
     def envelope(self):
@@ -229,7 +236,7 @@ class GeoPandasBase(object):
         The envelope of a geometry is the bounding rectangle. That is, the
         point or smallest rectangular polygon (with sides parallel to the
         coordinate axes) that contains the geometry."""
-        return _unary_geo('envelope', self)
+        return _delegate_property("envelope", self)
 
     @property
     def exterior(self):
@@ -239,7 +246,7 @@ class GeoPandasBase(object):
         Applies to GeoSeries containing only Polygons.
         """
         # TODO: return empty geometry for non-polygons
-        return _unary_geo('exterior', self)
+        return _delegate_property("exterior", self)
 
     @property
     def interiors(self):
@@ -253,34 +260,13 @@ class GeoPandasBase(object):
         inner_rings: Series of List
             Inner rings of each polygon in the GeoSeries.
         """
-
-        has_non_poly = False
-        inner_rings = []
-        for geom in self.geometry:
-            interior_ring_seq = getattr(geom, 'interiors', None)
-            # polygon case
-            if interior_ring_seq is not None:
-                inner_rings.append(list(interior_ring_seq))
-            # non-polygon case
-            else:
-                has_non_poly = True
-                inner_rings.append(None)
-        if has_non_poly:
-            warn("Only Polygon objects have interior rings. For other "
-                 "geometry types, None is returned.")
-
-        # _unary_op couldn't be used in order to warning to non-polygon and
-        # conversion to list.
-        return Series(inner_rings,
-                      index=self.index, dtype=object)
+        return _delegate_property("interiors", self)
 
     def representative_point(self):
         """Returns a ``GeoSeries`` of (cheaply computed) points that are
         guaranteed to be within each geometry.
         """
-        return gpd.GeoSeries([geom.representative_point()
-                              for geom in self.geometry],
-                             index=self.index)
+        return _delegate_geo_method("representative_point", self)
 
     #
     # Reduction operations that return a Shapely geometry
@@ -289,13 +275,13 @@ class GeoPandasBase(object):
     @property
     def cascaded_union(self):
         """Deprecated: Return the unary_union of all geometries"""
-        return cascaded_union(self.geometry.values)
+        return cascaded_union(np.asarray(self.geometry.values))
 
     @property
     def unary_union(self):
         """Returns a geometry containing the union of all geometries in the
         ``GeoSeries``."""
-        return unary_union(self.geometry.values)
+        return self.geometry.values.unary_union()
 
     #
     # Binary operations that return a pandas Series
@@ -318,7 +304,7 @@ class GeoPandasBase(object):
             The GeoSeries (elementwise) or geometric object to test if is
             contained.
         """
-        return _binary_op('contains', self, other)
+        return _binary_op("contains", self, other)
 
     def geom_equals(self, other):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
@@ -334,7 +320,7 @@ class GeoPandasBase(object):
             The GeoSeries (elementwise) or geometric object to test for
             equality.
         """
-        return _binary_op('equals', self, other)
+        return _binary_op("equals", self, other)
 
     def geom_almost_equals(self, other, decimal=6):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` if
@@ -350,12 +336,12 @@ class GeoPandasBase(object):
         decimal : int
             Decimal place presion used when testing for approximate equality.
         """
-        return _binary_op('almost_equals', self, other, decimal=decimal)
+        return _binary_op("almost_equals", self, other, decimal=decimal)
 
     def geom_equals_exact(self, other, tolerance):
         """Return True for all geometries that equal *other* to a given
         tolerance, else False"""
-        return _binary_op('equals_exact', self, other, tolerance=tolerance)
+        return _binary_op("equals_exact", self, other, tolerance=tolerance)
 
     def crosses(self, other):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
@@ -371,7 +357,7 @@ class GeoPandasBase(object):
             The GeoSeries (elementwise) or geometric object to test if is
             crossed.
         """
-        return _binary_op('crosses', self, other)
+        return _binary_op("crosses", self, other)
 
     def disjoint(self, other):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
@@ -386,7 +372,7 @@ class GeoPandasBase(object):
             The GeoSeries (elementwise) or geometric object to test if is
             disjoint.
         """
-        return _binary_op('disjoint', self, other)
+        return _binary_op("disjoint", self, other)
 
     def intersects(self, other):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
@@ -401,11 +387,11 @@ class GeoPandasBase(object):
             The GeoSeries (elementwise) or geometric object to test if is
             intersected.
         """
-        return _binary_op('intersects', self, other)
+        return _binary_op("intersects", self, other)
 
     def overlaps(self, other):
         """Return True for all geometries that overlap *other*, else False"""
-        return _binary_op('overlaps', self, other)
+        return _binary_op("overlaps", self, other)
 
     def touches(self, other):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
@@ -421,7 +407,7 @@ class GeoPandasBase(object):
             The GeoSeries (elementwise) or geometric object to test if is
             touched.
         """
-        return _binary_op('touches', self, other)
+        return _binary_op("touches", self, other)
 
     def within(self, other):
         """Returns a ``Series`` of ``dtype('bool')`` with value ``True`` for
@@ -442,7 +428,7 @@ class GeoPandasBase(object):
             geometry is within.
 
         """
-        return _binary_op('within', self, other)
+        return _binary_op("within", self, other)
 
     def distance(self, other):
         """Returns a ``Series`` containing the distance to `other`.
@@ -453,7 +439,7 @@ class GeoPandasBase(object):
             The Geoseries (elementwise) or geometric object to find the
             distance to.
         """
-        return _binary_op('distance', self, other)
+        return _binary_op("distance", self, other)
 
     #
     # Binary operations that return a GeoSeries
@@ -469,7 +455,7 @@ class GeoPandasBase(object):
             The Geoseries (elementwise) or geometric object to find the
             difference to.
         """
-        return _binary_geo('difference', self, other)
+        return _binary_geo("difference", self, other)
 
     def symmetric_difference(self, other):
         """Returns a ``GeoSeries`` of the symmetric difference of points in
@@ -484,7 +470,7 @@ class GeoPandasBase(object):
             The Geoseries (elementwise) or geometric object to find the
             symmetric difference to.
         """
-        return _binary_geo('symmetric_difference', self, other)
+        return _binary_geo("symmetric_difference", self, other)
 
     def union(self, other):
         """Returns a ``GeoSeries`` of the union of points in each geometry with
@@ -496,7 +482,7 @@ class GeoPandasBase(object):
             The Geoseries (elementwise) or geometric object to find the union
             with.
         """
-        return _binary_geo('union', self, other,)
+        return _binary_geo("union", self, other)
 
     def intersection(self, other):
         """Returns a ``GeoSeries`` of the intersection of points in each
@@ -508,7 +494,7 @@ class GeoPandasBase(object):
             The Geoseries (elementwise) or geometric object to find the
             intersection with.
         """
-        return _binary_geo('intersection', self, other)
+        return _binary_geo("intersection", self, other)
 
     #
     # Other operations
@@ -521,10 +507,10 @@ class GeoPandasBase(object):
 
         See ``GeoSeries.total_bounds`` for the limits of the entire series.
         """
-        bounds = np.array([geom.bounds for geom in self.geometry])
-        return DataFrame(bounds,
-                         columns=['minx', 'miny', 'maxx', 'maxy'],
-                         index=self.index)
+        bounds = GeometryArray(self.geometry.values).bounds
+        return DataFrame(
+            bounds, columns=["minx", "miny", "maxx", "maxy"], index=self.index
+        )
 
     @property
     def total_bounds(self):
@@ -534,11 +520,7 @@ class GeoPandasBase(object):
         See ``GeoSeries.bounds`` for the bounds of the geometries contained in
         the series.
         """
-        b = self.bounds
-        return np.array((b['minx'].min(),
-                         b['miny'].min(),
-                         b['maxx'].max(),
-                         b['maxy'].max()))
+        return GeometryArray(self.geometry.values).total_bounds
 
     @property
     def sindex(self):
@@ -561,22 +543,17 @@ class GeoPandasBase(object):
         resolution: int
             Optional, the resolution of the buffer around each vertex.
         """
-        if isinstance(distance, (np.ndarray, pd.Series)):
-            if len(distance) != len(self.index):
-                raise ValueError("Length of distance sequence does not match "
-                                 "length of the GeoSeries")
-            if isinstance(distance, pd.Series):
-                if not self.index.equals(distance.index):
-                    raise ValueError("Index values of distance sequence does "
-                                     "not match index values of the GeoSeries")
-            return gpd.GeoSeries(
-                [geom.buffer(dist, resolution, **kwargs)
-                 for geom, dist in zip(self.geometry, distance)],
-                index=self.index, crs=self.crs)
+        if isinstance(distance, pd.Series):
+            if not self.index.equals(distance.index):
+                raise ValueError(
+                    "Index values of distance sequence does "
+                    "not match index values of the GeoSeries"
+                )
+            distance = np.asarray(distance)
 
-        return gpd.GeoSeries([geom.buffer(distance, resolution, **kwargs)
-                              for geom in self.geometry],
-                             index=self.index, crs=self.crs)
+        return _delegate_geo_method(
+            "buffer", self, distance, resolution=resolution, **kwargs
+        )
 
     def simplify(self, *args, **kwargs):
         """Returns a ``GeoSeries`` containing a simplified representation of
@@ -594,9 +571,7 @@ class GeoPandasBase(object):
             False uses a quicker algorithm, but may produce self-intersecting
             or otherwise invalid geometries.
         """
-        return gpd.GeoSeries(
-            [geom.simplify(*args, **kwargs) for geom in self.geometry],
-            index=self.index, crs=self.crs)
+        return _delegate_geo_method("simplify", self, *args, **kwargs)
 
     def relate(self, other):
         """
@@ -614,7 +589,7 @@ class GeoPandasBase(object):
             The DE-9IM intersection matrices which describe
             the spatial relations of the other geometry.
         """
-        return _binary_op('relate', self, other)
+        return _binary_op("relate", self, other)
 
     def project(self, other, normalized=False):
         """
@@ -630,8 +605,7 @@ class GeoPandasBase(object):
 
         The project method is the inverse of interpolate.
         """
-
-        return _binary_op('project', self, other, normalized=normalized)
+        return _binary_op("project", self, other, normalized=normalized)
 
     def interpolate(self, distance, normalized=False):
         """
@@ -647,22 +621,33 @@ class GeoPandasBase(object):
             If normalized is True, distance will be interpreted as a fraction
             of the geometric object's length.
         """
-        if isinstance(distance, (np.ndarray, pd.Series)):
-            if len(distance) != len(self.index):
-                raise ValueError("Length of distance sequence does not match "
-                                 "length of the GeoSeries")
-            if isinstance(distance, pd.Series):
-                if not self.index.equals(distance.index):
-                    raise ValueError("Index values of distance sequence does "
-                                     "not match index values of the GeoSeries")
-            return gpd.GeoSeries(
-                [s.interpolate(dist, normalized=normalized)
-                 for (s, dist) in zip(self.geometry, distance)],
-                index=self.index, crs=self.crs)
+        if isinstance(distance, pd.Series):
+            if not self.index.equals(distance.index):
+                raise ValueError(
+                    "Index values of distance sequence does "
+                    "not match index values of the GeoSeries"
+                )
+            distance = np.asarray(distance)
+        return _delegate_geo_method(
+            "interpolate", self, distance, normalized=normalized
+        )
 
-        return gpd.GeoSeries([s.interpolate(distance, normalized=normalized)
-                              for s in self.geometry],
-                             index=self.index, crs=self.crs)
+    def affine_transform(self, matrix):
+        """Return a ``GeoSeries`` with translated geometries.
+
+        See http://shapely.readthedocs.io/en/stable/manual.html#shapely.affinity.affine_transform
+        for details.
+
+        Parameters
+        ----------
+        matrix: List or tuple
+            6 or 12 items for 2D or 3D transformations respectively.
+            For 2D affine transformations,
+            the 6 parameter matrix is [a, b, d, e, xoff, yoff]
+            For 3D affine transformations,
+            the 12 parameter matrix is [a, b, c, d, e, f, g, h, i, xoff, yoff, zoff]
+        """  # noqa (E501 link is longer than max line length)
+        return _delegate_geo_method("affine_transform", self, matrix)
 
     def translate(self, xoff=0.0, yoff=0.0, zoff=0.0):
         """Returns a ``GeoSeries`` with translated geometries.
@@ -676,12 +661,10 @@ class GeoPandasBase(object):
             Amount of offset along each dimension.
             xoff, yoff, and zoff for translation along the x, y, and z
             dimensions respectively.
-        """
-        return gpd.GeoSeries([affinity.translate(s, xoff, yoff, zoff)
-                              for s in self.geometry],
-                             index=self.index, crs=self.crs)
+        """  # noqa (E501 link is longer than max line length)
+        return _delegate_geo_method("translate", self, xoff, yoff, zoff)
 
-    def rotate(self, angle, origin='center', use_radians=False):
+    def rotate(self, angle, origin="center", use_radians=False):
         """Returns a ``GeoSeries`` with rotated geometries.
 
         See http://shapely.readthedocs.io/en/latest/manual.html#shapely.affinity.rotate
@@ -700,13 +683,11 @@ class GeoPandasBase(object):
         use_radians : boolean
             Whether to interpret the angle of rotation as degrees or radians
         """
-        return gpd.GeoSeries(
-            [affinity.rotate(s, angle, origin=origin,
-                             use_radians=use_radians)
-             for s in self.geometry],
-            index=self.index, crs=self.crs)
+        return _delegate_geo_method(
+            "rotate", self, angle, origin=origin, use_radians=use_radians
+        )
 
-    def scale(self, xfact=1.0, yfact=1.0, zfact=1.0, origin='center'):
+    def scale(self, xfact=1.0, yfact=1.0, zfact=1.0, origin="center"):
         """Returns a ``GeoSeries`` with scaled geometries.
 
         The geometries can be scaled by different factors along each
@@ -724,12 +705,9 @@ class GeoPandasBase(object):
             box center (default), 'centroid' for the geometry's 2D centroid, a
             Point object or a coordinate tuple (x, y, z).
         """
-        return gpd.GeoSeries(
-            [affinity.scale(s, xfact, yfact, zfact, origin=origin)
-             for s in self.geometry],
-            index=self.index, crs=self.crs)
+        return _delegate_geo_method("scale", self, xfact, yfact, zfact, origin=origin)
 
-    def skew(self, xs=0.0, ys=0.0, origin='center', use_radians=False):
+    def skew(self, xs=0.0, ys=0.0, origin="center", use_radians=False):
         """Returns a ``GeoSeries`` with skewed geometries.
 
         The geometries are sheared by angles along the x and y dimensions.
@@ -750,10 +728,9 @@ class GeoPandasBase(object):
         use_radians : boolean
             Whether to interpret the shear angle(s) as degrees or radians
         """
-        return gpd.GeoSeries(
-            [affinity.skew(s, xs, ys, origin=origin, use_radians=use_radians)
-             for s in self.geometry],
-            index=self.index, crs=self.crs)
+        return _delegate_geo_method(
+            "skew", self, xs, ys, origin=origin, use_radians=use_radians
+        )
 
     def explode(self):
         """
@@ -772,8 +749,9 @@ class GeoPandasBase(object):
         Example
         -------
         >>> gdf  # gdf is GeoSeries of MultiPoints
-        0                 (POINT (0 0), POINT (1 1))
-        1    (POINT (2 2), POINT (3 3), POINT (4 4))
+        0         MULTIPOINT (0 0, 1 1)
+        1    MULTIPOINT (2 2, 3 3, 4 4)
+        dtype: geometry
 
         >>> gdf.explode()
         0  0    POINT (0 0)
@@ -781,13 +759,13 @@ class GeoPandasBase(object):
         1  0    POINT (2 2)
            1    POINT (3 3)
            2    POINT (4 4)
-        dtype: object
+        dtype: geometry
 
         """
         index = []
         geometries = []
         for idx, s in self.geometry.iteritems():
-            if s.type.startswith('Multi') or s.type == 'GeometryCollection':
+            if s.type.startswith("Multi") or s.type == "GeometryCollection":
                 geoms = s.geoms
                 idxs = [(idx, i) for i in range(len(geoms))]
             else:
@@ -798,20 +776,28 @@ class GeoPandasBase(object):
         index = MultiIndex.from_tuples(index, names=self.index.names + [None])
         return gpd.GeoSeries(geometries, index=index).__finalize__(self)
 
+    @property
+    def cx(self):
+        """
+        Coordinate based indexer to select by intersection with bounding box.
 
-class _CoordinateIndexer(_NDFrameIndexer):
-    """
-    Coordinate based indexer to select by intersection with bounding box.
+        Format of input should be ``.cx[xmin:xmax, ymin:ymax]``. Any of
+        ``xmin``, ``xmax``, ``ymin``, and ``ymax`` can be provided, but input
+        must include a comma separating x and y slices. That is, ``.cx[:, :]``
+        will return the full series/frame, but ``.cx[:]`` is not implemented.
+        """
+        return _CoordinateIndexer(self)
 
-    Format of input should be ``.cx[xmin:xmax, ymin:ymax]``. Any of ``xmin``,
-    ``xmax``, ``ymin``, and ``ymax`` can be provided, but input must
-    include a comma separating x and y slices. That is, ``.cx[:, :]`` will
-    return the full series/frame, but ``.cx[:]`` is not implemented.
-    """
 
-    def _getitem_tuple(self, tup):
+class _CoordinateIndexer(object):
+    # see docstring GeoPandasBase.cx property above
+
+    def __init__(self, obj):
+        self.obj = obj
+
+    def __getitem__(self, key):
         obj = self.obj
-        xs, ys = tup
+        xs, ys = key
         # handle numeric values as x and/or y coordinate index
         if type(xs) is not slice:
             xs = slice(xs, xs)
@@ -821,9 +807,11 @@ class _CoordinateIndexer(_NDFrameIndexer):
         if xs.step is not None or ys.step is not None:
             warn("Ignoring step - full interval is used.")
         xmin, ymin, xmax, ymax = obj.total_bounds
-        bbox = box(xs.start if xs.start is not None else xmin,
-                   ys.start if ys.start is not None else ymin,
-                   xs.stop if xs.stop is not None else xmax,
-                   ys.stop if ys.stop is not None else ymax)
+        bbox = box(
+            xs.start if xs.start is not None else xmin,
+            ys.start if ys.start is not None else ymin,
+            xs.stop if xs.stop is not None else xmax,
+            ys.stop if ys.stop is not None else ymax,
+        )
         idx = obj.intersects(bbox)
         return obj[idx]
