@@ -3,17 +3,36 @@ import json
 import numpy as np
 import pandas as pd
 from pandas import DataFrame, Series
+
 from shapely.geometry import mapping, shape
-from shapely.geometry.base import BaseGeometry
-from six import string_types, PY3
 
-from geopandas.base import GeoPandasBase, _CoordinateIndexer
+from geopandas.array import GeometryArray, from_shapely
+from geopandas.base import GeoPandasBase, is_geometry_type
 from geopandas.geoseries import GeoSeries
-from geopandas.plotting import plot_dataframe
 import geopandas.io
+from geopandas.plotting import plot_dataframe
+
+DEFAULT_GEO_COLUMN_NAME = "geometry"
 
 
-DEFAULT_GEO_COLUMN_NAME = 'geometry'
+def _ensure_geometry(data):
+    """
+    Ensure the data is of geometry dtype or converted to it.
+
+    If input is a (Geo)Series, output is a GeoSeries, otherwise output
+    is GeometryArray.
+    """
+    if is_geometry_type(data):
+        if isinstance(data, Series):
+            return GeoSeries(data)
+        return data
+    else:
+        if isinstance(data, Series):
+            out = from_shapely(np.asarray(data))
+            return GeoSeries(out, index=data.index, name=data.name)
+        else:
+            out = from_shapely(data)
+            return out
 
 
 class GeoDataFrame(GeoPandasBase, DataFrame):
@@ -22,8 +41,8 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
     with geometry. In addition to the standard DataFrame constructor arguments,
     GeoDataFrame also accepts the following keyword arguments:
 
-    Keyword Arguments
-    -----------------
+    Parameters
+    ----------
     crs : str (optional)
         Coordinate system
     geometry : str or array (optional)
@@ -31,54 +50,68 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         column on GeoDataFrame.
     """
 
-    # XXX: This will no longer be necessary in pandas 0.17
-    _internal_names = ['_data', '_cacher', '_item_cache', '_cache',
-                       'is_copy', '_subtyp', '_index',
-                       '_default_kind', '_default_fill_value', '_metadata',
-                       '__array_struct__', '__array_interface__']
-
-    _metadata = ['crs', '_geometry_column_name']
+    _metadata = ["_crs", "_geometry_column_name"]
 
     _geometry_column_name = DEFAULT_GEO_COLUMN_NAME
 
     def __init__(self, *args, **kwargs):
-        crs = kwargs.pop('crs', None)
-        geometry = kwargs.pop('geometry', None)
+        crs = kwargs.pop("crs", None)
+        geometry = kwargs.pop("geometry", None)
         super(GeoDataFrame, self).__init__(*args, **kwargs)
+
+        # need to set this before calling self['geometry'], because
+        # getitem accesses crs
+        self._crs = None
         self.crs = crs
+
+        # set_geometry ensures the geometry data have the proper dtype,
+        # but is not called if `geometry=None` ('geometry' column present
+        # in the data), so therefore need to ensure it here manually
+        # but within a try/except because currently non-geometries are
+        # allowed in that case
+        # TODO do we want to raise / return normal DataFrame in this case?
+        if geometry is None and "geometry" in self.columns:
+            # only if we have actual geometry values -> call set_geometry
+            index = self.index
+            try:
+                self["geometry"] = _ensure_geometry(self["geometry"].values)
+            except TypeError:
+                pass
+            else:
+                if self.index is not index:
+                    # With pandas < 1.0 and an empty frame (no rows), the index
+                    # gets reset to a default RangeIndex -> set back the original
+                    # index if needed
+                    self.index = index
+                geometry = "geometry"
+
         if geometry is not None:
             self.set_geometry(geometry, inplace=True)
         self._invalidate_sindex()
 
-    # Serialize metadata (will no longer be necessary in pandas 0.17+)
-    # See https://github.com/pydata/pandas/pull/10557
-    def __getstate__(self):
-        meta = dict((k, getattr(self, k, None)) for k in self._metadata)
-        return dict(_data=self._data, _typ=self._typ,
-                    _metadata=self._metadata, **meta)
-
     def __setattr__(self, attr, val):
         # have to special case geometry b/c pandas tries to use as column...
-        if attr == 'geometry':
+        if attr == "geometry":
             object.__setattr__(self, attr, val)
         else:
             super(GeoDataFrame, self).__setattr__(attr, val)
 
     def _get_geometry(self):
         if self._geometry_column_name not in self:
-            raise AttributeError("No geometry data set yet (expected in"
-                                 " column '%s'." % self._geometry_column_name)
+            raise AttributeError(
+                "No geometry data set yet (expected in"
+                " column '%s'." % self._geometry_column_name
+            )
         return self[self._geometry_column_name]
 
     def _set_geometry(self, col):
-        # TODO: Use pandas' core.common.is_list_like() here.
-        if not isinstance(col, (list, np.ndarray, Series)):
-            raise ValueError("Must use a list-like to set the geometry"
-                             " property")
+        if not pd.api.types.is_list_like(col):
+            raise ValueError("Must use a list-like to set the geometry property")
         self.set_geometry(col, inplace=True)
 
-    geometry = property(fget=_get_geometry, fset=_set_geometry,
-                        doc="Geometry data for GeoDataFrame")
+    geometry = property(
+        fget=_get_geometry, fset=_set_geometry, doc="Geometry data for GeoDataFrame"
+    )
 
     def set_geometry(self, col, drop=False, inplace=False, crs=None):
         """
@@ -89,7 +122,7 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
 
         Parameters
         ----------
-        keys : column label or array
+        col : column label or array
         drop : boolean, default True
             Delete column to be used as the new geometry
         inplace : boolean, default False
@@ -115,20 +148,20 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
             frame = self.copy()
 
         if not crs:
-            crs = getattr(col, 'crs', self.crs)
+            crs = getattr(col, "crs", self.crs)
 
         to_remove = None
         geo_column_name = self._geometry_column_name
-        if isinstance(col, (Series, list, np.ndarray)):
+        if isinstance(col, (Series, list, np.ndarray, GeometryArray)):
             level = col
-        elif hasattr(col, 'ndim') and col.ndim != 1:
+        elif hasattr(col, "ndim") and col.ndim != 1:
             raise ValueError("Must pass array with one dimension only.")
         else:
             try:
                 level = frame[col].values
             except KeyError:
                 raise ValueError("Unknown column %s" % col)
-            except:
+            except Exception:
                 raise
             if drop:
                 to_remove = col
@@ -145,29 +178,64 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
             level.crs = crs
 
         # Check that we are using a listlike of geometries
-        if not all(isinstance(item, BaseGeometry) or not item for item in level):
-            raise TypeError("Input geometry column must contain valid geometry objects.")
+        level = _ensure_geometry(level)
+        index = frame.index
         frame[geo_column_name] = level
+        if frame.index is not index and len(frame.index) == len(index):
+            # With pandas < 1.0 and an empty frame (no rows), the index gets reset
+            # to a default RangeIndex -> set back the original index if needed
+            frame.index = index
         frame._geometry_column_name = geo_column_name
         frame.crs = crs
         frame._invalidate_sindex()
         if not inplace:
             return frame
 
+    def rename_geometry(self, col, inplace=False):
+        """
+        Renames the GeoDataFrame geometry column to
+        the specified name. By default yields a new object.
+
+        The original geometry column is replaced with the input.
+
+        Parameters
+        ----------
+        col : new geometry column label
+        inplace : boolean, default False
+            Modify the GeoDataFrame in place (do not create a new object)
+
+        Examples
+        --------
+        >>> df1 = df.rename_geometry('geom1')
+        >>> df1.geometry.name
+        'geom1'
+        >>> df.rename_geometry('geom1', inplace=True)
+        >>> df.geometry.name
+        'geom1'
+
+        Returns
+        -------
+        geodataframe : GeoDataFrame
+        """
+        geometry_col = self.geometry.name
+        if not inplace:
+            return self.rename(columns={geometry_col: col}).set_geometry(col, inplace)
+        self.rename(columns={geometry_col: col}, inplace=inplace)
+        self.set_geometry(col, inplace=inplace)
+
     @classmethod
     def from_file(cls, filename, **kwargs):
         """Alternate constructor to create a ``GeoDataFrame`` from a file.
 
         Can load a ``GeoDataFrame`` from a file in any format recognized by
-        `fiona`. See http://toblerity.org/fiona/manual.html for details.
+        `fiona`. See http://fiona.readthedocs.io/en/latest/manual.html for details.
 
         Parameters
         ----------
-
         filename : str
             File path or file handle to read from. Depending on which kwargs
             are included, the content of filename may vary. See
-            http://toblerity.org/fiona/README.html#usage for usage details.
+            http://fiona.readthedocs.io/en/latest/README.html#usage for usage details.
         kwargs : key-word arguments
             These arguments are passed to fiona.open, and can be used to
             access multi-layer data, data stored within archives (zip files),
@@ -175,7 +243,6 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
 
         Examples
         --------
-
         >>> df = geopandas.GeoDataFrame.from_file('nybb.shp')
         """
         return geopandas.io.file.read_file(filename, **kwargs)
@@ -218,8 +285,8 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         else:
             fs = features
 
-        if isinstance(fs, dict) and fs.get('type') == 'FeatureCollection':
-            features_lst = fs['features']
+        if isinstance(fs, dict) and fs.get("type") == "FeatureCollection":
+            features_lst = fs["features"]
         else:
             features_lst = features
 
@@ -230,19 +297,28 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
             else:
                 f = f
 
-            d = {'geometry': shape(f['geometry']) if f['geometry'] else None}
-            d.update(f['properties'])
+            d = {"geometry": shape(f["geometry"]) if f["geometry"] else None}
+            d.update(f["properties"])
             rows.append(d)
         df = GeoDataFrame(rows, columns=columns)
         df.crs = crs
         return df
 
     @classmethod
-    def from_postgis(cls, sql, con, geom_col='geom', crs=None,
-                     hex_encoded=True, index_col=None, coerce_float=True,
-                     params=None):
-        """Alternate constructor to create a ``GeoDataFrame`` from a sql query
-        containing a geometry column.
+    def from_postgis(
+        cls,
+        sql,
+        con,
+        geom_col="geom",
+        crs=None,
+        index_col=None,
+        coerce_float=True,
+        parse_dates=None,
+        params=None,
+    ):
+        """
+        Alternate constructor to create a ``GeoDataFrame`` from a sql query
+        containing a geometry column in WKB representation.
 
         Parameters
         ----------
@@ -252,29 +328,45 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
             column name to convert to shapely geometries
         crs : optional
             Coordinate reference system to use for the returned GeoDataFrame
-        hex_encoded : bool, optional
-            Whether the geometry is in a hex-encoded string. Default is True,
-            standard for postGIS.
         index_col : string or list of strings, optional, default: None
             Column(s) to set as index(MultiIndex)
         coerce_float : boolean, default True
             Attempt to convert values of non-string, non-numeric objects (like
             decimal.Decimal) to floating point, useful for SQL result sets
-        params : list, tuple or dict, optional, default: None
+        parse_dates : list or dict, default None
+            - List of column names to parse as dates.
+            - Dict of ``{column_name: format string}`` where format string is
+              strftime compatible in case of parsing string times, or is one of
+              (D, s, ns, ms, us) in case of parsing integer timestamps.
+            - Dict of ``{column_name: arg dict}``, where the arg dict
+              corresponds to the keyword arguments of
+              :func:`pandas.to_datetime`. Especially useful with databases
+              without native Datetime support, such as SQLite.
+        params : list, tuple or dict, optional, default None
             List of parameters to pass to execute method.
 
         Examples
         --------
-        >>> sql = "SELECT geom, highway FROM roads;"
+        >>> sql = "SELECT geom, highway FROM roads"
+        SpatiaLite
+        >>> sql = "SELECT ST_Binary(geom) AS geom, highway FROM roads"
         >>> df = geopandas.GeoDataFrame.from_postgis(sql, con)
         """
 
         df = geopandas.io.sql.read_postgis(
-                sql, con, geom_col=geom_col, crs=crs, hex_encoded=hex_encoded,
-                index_col=index_col, coerce_float=coerce_float, params=params)
+            sql,
+            con,
+            geom_col=geom_col,
+            crs=crs,
+            index_col=index_col,
+            coerce_float=coerce_float,
+            parse_dates=parse_dates,
+            params=params,
+        )
+
         return df
 
-    def to_json(self, na='null', show_bbox=False, **kwargs):
+    def to_json(self, na="null", show_bbox=False, **kwargs):
         """
         Returns a GeoJSON representation of the ``GeoDataFrame`` as a string.
 
@@ -310,9 +402,9 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         This differs from `_to_geo()` only in that it is a property with
         default args instead of a method
         """
-        return self._to_geo(na='null', show_bbox=True)
+        return self._to_geo(na="null", show_bbox=True)
 
-    def iterfeatures(self, na='null', show_bbox=False):
+    def iterfeatures(self, na="null", show_bbox=False):
         """
         Returns an iterator that yields feature dictionaries that comply with
         __geo_interface__
@@ -328,45 +420,53 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
             * keep: output the missing entries as NaN
 
         show_bbox : include bbox (bounds) in the geojson. default False
-
         """
-        def fill_none(row):
-            """
-            Takes in a Series, converts to a dictionary with null values
-            set to None
+        if na not in ["null", "drop", "keep"]:
+            raise ValueError("Unknown na method {0}".format(na))
 
-            """
-            na_keys = row.index[row.isnull()]
-            d = row.to_dict()
-            for k in na_keys:
-                d[k] = None
-            return d
+        ids = np.array(self.index, copy=False)
+        geometries = np.array(self[self._geometry_column_name], copy=False)
 
-        # na_methods must take in a Series and return dict
-        na_methods = {'null': fill_none,
-                      'drop': lambda row: row.dropna().to_dict(),
-                      'keep': lambda row: row.to_dict()}
+        properties_cols = self.columns.difference([self._geometry_column_name])
 
-        if na not in na_methods:
-            raise ValueError('Unknown na method {0}'.format(na))
-        f = na_methods[na]
+        if len(properties_cols) > 0:
+            # convert to object to get python scalars.
+            properties = self[properties_cols].astype(object).values
+            if na == "null":
+                properties[pd.isnull(self[properties_cols]).values] = None
 
-        for name, row in self.iterrows():
-            properties = f(row)
-            del properties[self._geometry_column_name]
+            for i, row in enumerate(properties):
+                geom = geometries[i]
 
-            feature = {
-                'id': str(name),
-                'type': 'Feature',
-                'properties': properties,
-                'geometry': mapping(row[self._geometry_column_name])
-                            if row[self._geometry_column_name] else None
-            }
+                if na == "drop":
+                    properties_items = {
+                        k: v for k, v in zip(properties_cols, row) if not pd.isnull(v)
+                    }
+                else:
+                    properties_items = {k: v for k, v in zip(properties_cols, row)}
 
-            if show_bbox:
-                feature['bbox'] = row.geometry.bounds
+                feature = {
+                    "id": str(ids[i]),
+                    "type": "Feature",
+                    "properties": properties_items,
+                    "geometry": mapping(geom) if geom else None,
+                }
 
-            yield feature
+                if show_bbox:
+                    feature["bbox"] = geom.bounds if geom else None
+                yield feature
+
+        else:
+            for fid, geom in zip(ids, geometries):
+                feature = {
+                    "id": str(fid),
+                    "type": "Feature",
+                    "properties": {},
+                    "geometry": mapping(geom) if geom else None,
+                }
+                if show_bbox:
+                    feature["bbox"] = geom.bounds if geom else None
+                yield feature
 
     def _to_geo(self, **kwargs):
         """
@@ -374,16 +474,19 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         representation of the GeoDataFrame.
 
         """
-        geo = {'type': 'FeatureCollection',
-               'features': list(self.iterfeatures(**kwargs))}
+        geo = {
+            "type": "FeatureCollection",
+            "features": list(self.iterfeatures(**kwargs)),
+        }
 
-        if kwargs.get('show_bbox', False):
-            geo['bbox'] = tuple(self.total_bounds)
+        if kwargs.get("show_bbox", False):
+            geo["bbox"] = tuple(self.total_bounds)
 
         return geo
 
-    def to_file(self, filename, driver="ESRI Shapefile", schema=None,
-                **kwargs):
+    def to_file(
+        self, filename, driver="ESRI Shapefile", schema=None, index=None, **kwargs
+    ):
         """Write the ``GeoDataFrame`` to a file.
 
         By default, an ESRI shapefile is written, but any OGR data source
@@ -402,23 +505,39 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         schema : dict, default: None
             If specified, the schema dictionary is passed to Fiona to
             better control how the file is written.
+        index : bool, default None
+            If True, write index into one or more columns (for MultiIndex).
+            Default None writes the index into one or more columns only if
+            the index is named, is a MultiIndex, or has a non-integer data
+            type. If False, no index is written.
+
+            .. versionadded:: 0.7
+                Previously the index was not written.
 
         Notes
         -----
         The extra keyword arguments ``**kwargs`` are passed to fiona.open and
         can be used to write to multi-layer data, store data within archives
         (zip files), etc.
+
+        The format drivers will attempt to detect the encoding of your data, but
+        may fail. In this case, the proper encoding can be specified explicitly
+        by using the encoding keyword parameter, e.g. ``encoding='utf-8'``.
+
+        See Also
+        --------
+        GeoSeries.to_file
         """
         from geopandas.io.file import to_file
-        to_file(self, filename, driver, schema, **kwargs)
+
+        to_file(self, filename, driver, schema, index, **kwargs)
 
     def to_crs(self, crs=None, epsg=None, inplace=False):
         """Transform geometries to a new coordinate reference system.
 
         Transform all geometries in a GeoSeries to a different coordinate
         reference system.  The ``crs`` attribute on the current GeoSeries must
-        be set.  Either ``crs`` in string or dictionary form or an EPSG code
-        may be specified for output.
+        be set.  Either ``crs`` or ``epsg`` may be specified for output.
 
         This method will transform all points in all objects.  It has no notion
         or projecting entire geometries.  All segments joining points are
@@ -428,9 +547,11 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
 
         Parameters
         ----------
-        crs : dict or str
-            Output projection parameters as string or in dictionary form.
-        epsg : int
+        crs : pyproj.CRS, optional if `epsg` is specified
+            The value can be anything accepted
+            by :meth:`pyproj.CRS.from_user_input`, such as an authority
+            string (eg "EPSG:4326") or a WKT string.
+        epsg : int, optional if `crs` is specified
             EPSG code specifying output projection.
         inplace : bool, optional, default: False
             Whether to return a new GeoDataFrame or do the transformation in
@@ -454,7 +575,7 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         """
         result = super(GeoDataFrame, self).__getitem__(key)
         geo_col = self._geometry_column_name
-        if isinstance(key, string_types) and key == geo_col:
+        if isinstance(key, str) and key == geo_col:
             result.__class__ = GeoSeries
             result.crs = self.crs
             result._invalidate_sindex()
@@ -472,6 +593,26 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
     #
 
     def merge(self, *args, **kwargs):
+        r"""Merge two ``GeoDataFrame`` objects with a database-style join.
+
+        Returns a ``GeoDataFrame`` if a geometry column is present; otherwise,
+        returns a pandas ``DataFrame``.
+
+        Returns
+        -------
+        GeoDataFrame or DataFrame
+
+        Notes
+        -----
+        The extra arguments ``*args`` and keyword arguments ``**kwargs`` are
+        passed to DataFrame.merge.
+
+        Reference
+        ---------
+        https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas\
+        .DataFrame.merge.html
+
+        """
         result = DataFrame.merge(self, *args, **kwargs)
         geo_col = self._geometry_column_name
         if isinstance(result, DataFrame) and geo_col in result:
@@ -490,11 +631,11 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
     def __finalize__(self, other, method=None, **kwargs):
         """propagate metadata from other to self """
         # merge operation: using metadata of the left object
-        if method == 'merge':
+        if method == "merge":
             for name in self._metadata:
                 object.__setattr__(self, name, getattr(other.left, name, None))
         # concat operation: using metadata of the first object
-        elif method == 'concat':
+        elif method == "concat":
             for name in self._metadata:
                 object.__setattr__(self, name, getattr(other.objs[0], name, None))
         else:
@@ -502,25 +643,6 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
                 object.__setattr__(self, name, getattr(other, name, None))
         return self
 
-    def copy(self, deep=True):
-        """
-        Make a copy of this GeoDataFrame object
-
-        Parameters
-        ----------
-        deep : boolean, default True
-            Make a deep copy, i.e. also copy data
-
-        Returns
-        -------
-        copy : GeoDataFrame
-        """
-        # FIXME: this will likely be unnecessary in pandas >= 0.13
-        data = self._data
-        if deep:
-            data = data.copy()
-        return GeoDataFrame(data).__finalize__(self)
-
     def plot(self, *args, **kwargs):
         """Generate a plot of the geometries in the ``GeoDataFrame``.
 
@@ -535,8 +657,7 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
 
     plot.__doc__ = plot_dataframe.__doc__
 
-
-    def dissolve(self, by=None, aggfunc='first', as_index=True):
+    def dissolve(self, by=None, aggfunc="first", as_index=True):
         """
         Dissolve geometries within `groupby` into single observation.
         This is accomplished by applying the `unary_union` method
@@ -564,13 +685,14 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         data = self.drop(labels=self.geometry.name, axis=1)
         aggregated_data = data.groupby(by=by).agg(aggfunc)
 
-
         # Process spatial component
         def merge_geometries(block):
             merged_geom = block.unary_union
             return merged_geom
 
-        g = self.groupby(by=by, group_keys=False)[self.geometry.name].agg(merge_geometries)
+        g = self.groupby(by=by, group_keys=False)[self.geometry.name].agg(
+            merge_geometries
+        )
 
         # Aggregate
         aggregated_geometry = GeoDataFrame(g, geometry=self.geometry.name, crs=self.crs)
@@ -610,8 +732,8 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         exploded_index = exploded_geom.columns[0]
 
         df = pd.concat(
-            [df_copy.drop(df_copy._geometry_column_name, axis=1),
-             exploded_geom], axis=1)
+            [df_copy.drop(df_copy._geometry_column_name, axis=1), exploded_geom], axis=1
+        )
         # reset to MultiIndex, otherwise df index is only first level of
         # exploded GeoSeries index.
         df.set_index(exploded_index, append=True, inplace=True)
@@ -619,21 +741,41 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         geo_df = df.set_geometry(self._geometry_column_name)
         return geo_df
 
+    # overrides the pandas astype method to ensure the correct return type
+    def astype(self, dtype, copy=True, errors="raise", **kwargs):
+        """
+        Cast a pandas object to a specified dtype ``dtype``.
+
+        Returns a GeoDataFrame when the geometry column is kept as geometries,
+        otherwise returns a pandas DataFrame.
+
+        See the pandas.DataFrame.astype docstring for more details.
+
+        Returns
+        -------
+        GeoDataFrame or DataFrame
+        """
+        df = super(GeoDataFrame, self).astype(dtype, copy=copy, errors=errors, **kwargs)
+
+        try:
+            geoms = df[self._geometry_column_name]
+            if is_geometry_type(geoms):
+                return geopandas.GeoDataFrame(df, geometry=self._geometry_column_name)
+        except KeyError:
+            pass
+        # if the geometry column is converted to non-geometries or did not exist
+        # do not return a GeoDataFrame
+        return pd.DataFrame(df)
+
 
 def _dataframe_set_geometry(self, col, drop=False, inplace=False, crs=None):
     if inplace:
-        raise ValueError("Can't do inplace setting when converting from"
-                         " DataFrame to GeoDataFrame")
+        raise ValueError(
+            "Can't do inplace setting when converting from DataFrame to GeoDataFrame"
+        )
     gf = GeoDataFrame(self)
     # this will copy so that BlockManager gets copied
     return gf.set_geometry(col, drop=drop, inplace=False, crs=crs)
 
-if PY3:
-    DataFrame.set_geometry = _dataframe_set_geometry
-else:
-    import types
-    DataFrame.set_geometry = types.MethodType(_dataframe_set_geometry, None,
-                                              DataFrame)
 
-
-GeoDataFrame._create_indexer('cx', _CoordinateIndexer)
+DataFrame.set_geometry = _dataframe_set_geometry
