@@ -36,6 +36,5 @@ if mods:
         blacklist
     )
     call = [sys.executable, "-c", code]
-    # TODO(py3) update with subprocess.run once python 2.7 is dropped
-    returncode = subprocess.call(call, stderr=subprocess.STDOUT)
+    returncode = subprocess.run(call).returncode
     assert returncode == 0
