@@ -1,15 +1,16 @@
-from __future__ import absolute_import
-
+from .crs import explicit_crs_from_epsg
 from .geocoding import geocode, reverse_geocode
 from .overlay import overlay
 from .sjoin import sjoin
 from .util import collect
-from .crs import explicit_crs_from_epsg
+from .clip import clip
 
 __all__ = [
-    'overlay',
-    'sjoin',
-    'geocode',
-    'reverse_geocode',
-    'collect',
+    "collect",
+    "explicit_crs_from_epsg",
+    "geocode",
+    "overlay",
+    "reverse_geocode",
+    "sjoin",
+    "clip",
 ]
